@@ -4,5 +4,6 @@ var searchData=
   ['openness_1',['Openness',['../classTreeViewItem.html#aeb42402ed8e34ef5af931a762fd55bbd',1,'TreeViewItem']]],
   ['operatingsystemtype_2',['OperatingSystemType',['../classSystemStats.html#a7697c468b5f6c391096ab483690b68ea',1,'SystemStats']]],
   ['optionflags_3',['OptionFlags',['../classTemporaryFile.html#af04f4ef2ea1bee0b20cdb4c072442e8d',1,'TemporaryFile']]],
-  ['orientation_4',['Orientation',['../classMidiKeyboardComponent.html#a6f6844672df93f8f631fa7e22cf0cdaf',1,'MidiKeyboardComponent::Orientation()'],['../classTabbedButtonBar.html#a63e34dd62f1b80ec99412c6115b39afb',1,'TabbedButtonBar::Orientation()']]]
+  ['orientation_4',['Orientation',['../classKeyboardComponentBase.html#aa131ceb312997c3b5f07c840772509be',1,'KeyboardComponentBase::Orientation()'],['../classTabbedButtonBar.html#a63e34dd62f1b80ec99412c6115b39afb',1,'TabbedButtonBar::Orientation()']]],
+  ['overwritefiles_5',['OverwriteFiles',['../classZipFile.html#af388c9181c7270d0c863c898238dc93c',1,'ZipFile']]]
 ];
