@@ -33,8 +33,8 @@ var searchData=
   ['handlemouseevent_30',['handleMouseEvent',['../classComponentPeer.html#a744403dd1c8970e1ed742ee8d60c0011',1,'ComponentPeer']]],
   ['handlemousewheel_31',['handleMouseWheel',['../classComponentPeer.html#a9d8e4c4c9a151d697d0e5e06d0634756',1,'ComponentPeer']]],
   ['handlemovedorresized_32',['handleMovedOrResized',['../classComponentPeer.html#a8fb507144ba1144b75b63da1075807b9',1,'ComponentPeer']]],
-  ['handlenoteoff_33',['handleNoteOff',['../classMidiKeyboardState_1_1Listener.html#aedc74bd79578cb19edba66d38e9a93cf',1,'MidiKeyboardState::Listener::handleNoteOff()'],['../classMidiKeyboardComponent.html#a808c146824bf5635e1e2c1a101e761b7',1,'MidiKeyboardComponent::handleNoteOff()'],['../classMidiMessageCollector.html#a07e1a9bbeb9131dbe8d55431bb166ee8',1,'MidiMessageCollector::handleNoteOff()']]],
-  ['handlenoteon_34',['handleNoteOn',['../classMidiKeyboardState_1_1Listener.html#a854381a64354389e0cb2c15ec1fb4b01',1,'MidiKeyboardState::Listener::handleNoteOn()'],['../classMidiMessageCollector.html#a0e6368630ea8c456c79f86d8aebcaeb6',1,'MidiMessageCollector::handleNoteOn()'],['../classMidiKeyboardComponent.html#a92c81b4d77a09fbe9de21af2040d98d5',1,'MidiKeyboardComponent::handleNoteOn()']]],
+  ['handlenoteoff_33',['handleNoteOff',['../classMidiMessageCollector.html#a07e1a9bbeb9131dbe8d55431bb166ee8',1,'MidiMessageCollector::handleNoteOff()'],['../classMidiKeyboardState_1_1Listener.html#aedc74bd79578cb19edba66d38e9a93cf',1,'MidiKeyboardState::Listener::handleNoteOff()']]],
+  ['handlenoteon_34',['handleNoteOn',['../classMidiMessageCollector.html#a0e6368630ea8c456c79f86d8aebcaeb6',1,'MidiMessageCollector::handleNoteOn()'],['../classMidiKeyboardState_1_1Listener.html#a854381a64354389e0cb2c15ec1fb4b01',1,'MidiKeyboardState::Listener::handleNoteOn()']]],
   ['handlenotification_35',['handleNotification',['../structPushNotifications_1_1Listener.html#a36312f58ade7b38fd3167fe5a68376d2',1,'PushNotifications::Listener']]],
   ['handlenotificationaction_36',['handleNotificationAction',['../structPushNotifications_1_1Listener.html#a694cedbf97aef85f1f4d4885475324f7',1,'PushNotifications::Listener']]],
   ['handlepaint_37',['handlePaint',['../classComponentPeer.html#a360713977c8a8d38657247b16ff4e836',1,'ComponentPeer']]],
@@ -75,59 +75,63 @@ var searchData=
   ['haschangedsincesaved_72',['hasChangedSinceSaved',['../classFileBasedDocument.html#a5676fb4537c68957616bd24f54b58f22',1,'FileBasedDocument']]],
   ['haschangedsincesavepoint_73',['hasChangedSinceSavePoint',['../classCodeDocument.html#a4c3047eee0dad38555cf546c3ea3c15f',1,'CodeDocument']]],
   ['hascontrolpanel_74',['hasControlPanel',['../classAudioIODevice.html#ab85840f9ead545d0b3664d55158fd581',1,'AudioIODevice']]],
-  ['haseditor_75',['hasEditor',['../classAudioProcessor.html#a00be8f595da09ba01d74cb7c52b8fb81',1,'AudioProcessor::hasEditor()'],['../classAudioProcessorGraph_1_1AudioGraphIOProcessor.html#aa0e5fd5f05d014cbb01c0bbfa651abdc',1,'AudioProcessorGraph::AudioGraphIOProcessor::hasEditor()'],['../classAudioProcessorGraph.html#afdb5ca50f8d3ffef636be2b9dbdf08cf',1,'AudioProcessorGraph::hasEditor()']]],
+  ['haseditor_75',['hasEditor',['../classAudioProcessorGraph_1_1AudioGraphIOProcessor.html#aa0e5fd5f05d014cbb01c0bbfa651abdc',1,'AudioProcessorGraph::AudioGraphIOProcessor::hasEditor()'],['../classAudioProcessor.html#a00be8f595da09ba01d74cb7c52b8fb81',1,'AudioProcessor::hasEditor()'],['../classAudioProcessorGraph.html#afdb5ca50f8d3ffef636be2b9dbdf08cf',1,'AudioProcessorGraph::hasEditor()']]],
   ['hasfileextension_76',['hasFileExtension',['../classFile.html#a9a5b9f97e5e94aa43dd5df683543e1b1',1,'File']]],
   ['hasfma3_77',['hasFMA3',['../classSystemStats.html#a29437caec1936a765542ec3ec5e21cd1',1,'SystemStats']]],
   ['hasfma4_78',['hasFMA4',['../classSystemStats.html#af0867e25b93cb36f08552f84bc29b59f',1,'SystemStats']]],
   ['hasfocus_79',['hasFocus',['../classAccessibilityHandler.html#a0ccacf2fd854ed39a4988039dd573054',1,'AccessibilityHandler']]],
-  ['hash_80',['hash',['../classString.html#a317bebf3259d5fefa6a2558b65ae2f77',1,'String::hash()'],['../classUuid.html#aaa9e337833ead2cb48039a09ddcd8106',1,'Uuid::hash()']]],
-  ['hashcode_81',['hashCode',['../classFile.html#ae5548575e6854b9837e5b42fc8df0e98',1,'File::hashCode()'],['../classFileInputSource.html#a95b676eefdd0f1b2978d9c31a6af5d10',1,'FileInputSource::hashCode()'],['../classInputSource.html#a1fe754d44724da8eaef055c496ca4140',1,'InputSource::hashCode()'],['../classURLInputSource.html#a289bcfa8603911b61cd057ea0dd63646',1,'URLInputSource::hashCode()'],['../classString.html#ad8ca5cb11984df03ff9697442da5ae4b',1,'String::hashCode()']]],
-  ['hashcode64_82',['hashCode64',['../classFile.html#ad0075226638584f6fb30c0d515e182e9',1,'File::hashCode64()'],['../classString.html#ad71be66a9c181abae185b84f7cec5f17',1,'String::hashCode64()']]],
-  ['hashmap_83',['HashMap',['../classHashMap.html#a4d6d41cfc524ccc0a73f0251d7fc1fab',1,'HashMap']]],
-  ['hasidenticalcontentto_84',['hasIdenticalContentTo',['../classFile.html#ad3170a56847a243b475a72ccc9968089',1,'File']]],
-  ['haskeyboardfocus_85',['hasKeyboardFocus',['../classComponent.html#abf76cf5c3550c5c83bc585f86429b397',1,'Component']]],
-  ['hasmethod_86',['hasMethod',['../classDynamicObject.html#a530ccfe2318fb705fe4b4c9a07861788',1,'DynamicObject']]],
-  ['hasmmx_87',['hasMMX',['../classSystemStats.html#a245726d89f0a6cf232b70ff7d89652e5',1,'SystemStats']]],
-  ['hasmousecursor_88',['hasMouseCursor',['../classMouseInputSource.html#ad2b2d3176e07d9672e949dc88135f532',1,'MouseInputSource']]],
-  ['hasmousewheel_89',['hasMouseWheel',['../classMouseInputSource.html#a691068a9661fb11b3e7b10f51a4254b0',1,'MouseInputSource']]],
-  ['hasmovedsignificantlysincepressed_90',['hasMovedSignificantlySincePressed',['../classMouseInputSource.html#a50d0b35cef0fc91851c18e0c242f6adc',1,'MouseInputSource']]],
-  ['hasname_91',['hasName',['../structGridItem_1_1Property.html#a7ef06fbb3b2ad9644c11b54d2ed6986d',1,'GridItem::Property']]],
-  ['hasneon_92',['hasNeon',['../classSystemStats.html#a0e193b24d50ed44287099c8fbd879311',1,'SystemStats']]],
-  ['hasproperty_93',['hasProperty',['../classValueTree.html#a0dbec0d665fb9d57b9fd7b3189ec0ee0',1,'ValueTree::hasProperty()'],['../classvar.html#a1ac3c09cc21b32c4baa0f520c8783908',1,'var::hasProperty()'],['../classDynamicObject.html#a600910b3145a802f247b456f95b43e5f',1,'DynamicObject::hasProperty()']]],
-  ['hassametypeas_94',['hasSameTypeAs',['../classvar.html#a6357525c383c7d52c43d1db7d0669f34',1,'var']]],
-  ['hasseparateinputsandoutputs_95',['hasSeparateInputsAndOutputs',['../classAudioIODeviceType.html#ac87c3129c8e55018e968225b4a47dc74',1,'AudioIODeviceType']]],
-  ['hasspan_96',['hasSpan',['../structGridItem_1_1Property.html#a1e9afac3f936a5a048b15ee2784d7a92',1,'GridItem::Property']]],
-  ['hassse_97',['hasSSE',['../classSystemStats.html#ad5f3b624e4b0d32db1c5702ee039a765',1,'SystemStats']]],
-  ['hassse2_98',['hasSSE2',['../classSystemStats.html#a55e24b924d9c64e019f1efe1888d2963',1,'SystemStats']]],
-  ['hassse3_99',['hasSSE3',['../classSystemStats.html#aa9ffa8da005c3311eda3ee34ecdd5b28',1,'SystemStats']]],
-  ['hassse41_100',['hasSSE41',['../classSystemStats.html#ab46b181da7ecf6c0f96e865b1a91e6f3',1,'SystemStats']]],
-  ['hassse42_101',['hasSSE42',['../classSystemStats.html#a1b3861b105869d8062a539142da7e741',1,'SystemStats']]],
-  ['hasssse3_102',['hasSSSE3',['../classSystemStats.html#afd53593c782c3770106954ace47ce25c',1,'SystemStats']]],
-  ['hasstopmessagebeensent_103',['hasStopMessageBeenSent',['../classMessageManager.html#a3b51c7c37417fea8c4f47ebb7913ddba',1,'MessageManager']]],
-  ['hasstreamfinished_104',['hasStreamFinished',['../classAudioTransportSource.html#a4914381d34ed8bff499ca878c2be83fb',1,'AudioTransportSource']]],
-  ['hastagname_105',['hasTagName',['../classXmlElement.html#ac50bc4ce0db92b84baf4baf1b9c4de1d',1,'XmlElement']]],
-  ['hastagnameignoringnamespace_106',['hasTagNameIgnoringNamespace',['../classXmlElement.html#abcf184f1ddfb5cbec32f20b9adefb4c7',1,'XmlElement']]],
-  ['hastype_107',['hasType',['../classValueTree.html#a5d41bc2066cae65b69aa614aa0f68ff1',1,'ValueTree']]],
-  ['haswatchedcomponentbeendeleted_108',['hasWatchedComponentBeenDeleted',['../classPopupMenu_1_1Options.html#a6411ef9fb0d046aaa1c9b1e8c8a7e1e4',1,'PopupMenu::Options']]],
-  ['haswriteaccess_109',['hasWriteAccess',['../classFile.html#a5335004d1a8ec1673c616358adee00e7',1,'File']]],
-  ['heapblock_110',['HeapBlock',['../classHeapBlock.html#a720865797ff4f5e9e92432b0b231d110',1,'HeapBlock::HeapBlock()=default'],['../classHeapBlock.html#a7b5c4b5a56551744a36f68eefc27f6d7',1,'HeapBlock::HeapBlock(SizeType numElements)'],['../classHeapBlock.html#a6fa48a9a24fa7b9b84967c1c6aa29e24',1,'HeapBlock::HeapBlock(SizeType numElements, bool initialiseToZero)'],['../classHeapBlock.html#a43e44081c3cbef5f634dd5a2a58cd1bd',1,'HeapBlock::HeapBlock(HeapBlock &amp;&amp;other) noexcept'],['../classHeapBlock.html#a43360d0b67112a64db4c131cfe976a31',1,'HeapBlock::HeapBlock(HeapBlock&lt; OtherElementType, otherThrowOnFailure &gt; &amp;&amp;other) noexcept']]],
-  ['heavyweightleakedobjectdetector_111',['HeavyweightLeakedObjectDetector',['../classHeavyweightLeakedObjectDetector.html#ae84f4df4ce1826d3bf438bab330d2831',1,'HeavyweightLeakedObjectDetector::HeavyweightLeakedObjectDetector() noexcept'],['../classHeavyweightLeakedObjectDetector.html#a05a37f04096dfe2c59d654f87fb91c5f',1,'HeavyweightLeakedObjectDetector::HeavyweightLeakedObjectDetector(const HeavyweightLeakedObjectDetector &amp;) noexcept']]],
-  ['hexagonal_112',['hexagonal',['../classAudioChannelSet.html#a7ed53c9a23d40bd2dd50e1d7129837f8',1,'AudioChannelSet']]],
-  ['hide_113',['hide',['../classProcess.html#a01a7ddde215bcef03cd16587ed4b0a64',1,'Process']]],
-  ['hidecursor_114',['hideCursor',['../classMouseInputSource.html#a61bc07273b91b328bcff92e721a2461e',1,'MouseInputSource']]],
-  ['hideeditor_115',['hideEditor',['../classLabel.html#a6f5fd9653da51af4720d1ac5e54f18d8',1,'Label']]],
-  ['hideinfobubble_116',['hideInfoBubble',['../classSystemTrayIconComponent.html#ad9e5f01b380d85df60bc76dcb07baefc',1,'SystemTrayIconComponent']]],
-  ['hidepopup_117',['hidePopup',['../classComboBox.html#a68c3355b300f275af9962d772665fd53',1,'ComboBox']]],
-  ['hidetextbox_118',['hideTextBox',['../classSlider.html#a0780c7da80f4d487703e8247e92bea21',1,'Slider']]],
-  ['hidetip_119',['hideTip',['../classTooltipWindow.html#a917c164d878207aceb22a1c71a541731',1,'TooltipWindow']]],
-  ['hidewaitcursor_120',['hideWaitCursor',['../classMouseCursor.html#a4671d39f6abcc1ca73fd8d95cf1e4355',1,'MouseCursor']]],
-  ['highresolutiontickstoseconds_121',['highResolutionTicksToSeconds',['../classTime.html#a3c4d54513d5d2be78a790cfd0b8c0493',1,'Time']]],
-  ['highresolutiontimer_122',['HighResolutionTimer',['../classHighResolutionTimer.html#ac79eb2389b1d52cd4a387836fe9ce860',1,'HighResolutionTimer']]],
-  ['hirestimercallback_123',['hiResTimerCallback',['../classHighResolutionTimer.html#a38fac5960301220b28b687817e4e7598',1,'HighResolutionTimer']]],
-  ['hittest_124',['hitTest',['../classResizableCornerComponent.html#acc3a046566ad8ab5aa5318b3a943d2fc',1,'ResizableCornerComponent::hitTest()'],['../classCallOutBox.html#a916cce375fb38ac4e77e4a8ef27591b6',1,'CallOutBox::hitTest()'],['../classLassoComponent.html#ab67925a4436687bc41437c8460de710d',1,'LassoComponent::hitTest()'],['../classTabBarButton.html#ac6e24e3e9b5001e36a3014692257ea03',1,'TabBarButton::hitTest()'],['../classResizableBorderComponent.html#acd797e21238848968eb9957106590253',1,'ResizableBorderComponent::hitTest()'],['../classDrawableShape.html#ab5862ed42c7976a43791f56ae6173c27',1,'DrawableShape::hitTest()'],['../classDrawableImage.html#a0a6bd602f7d8dd85366b11b7419209ed',1,'DrawableImage::hitTest()'],['../classComponent.html#a2da9631236e1cbf1b340454209a6c9e0',1,'Component::hitTest()'],['../classImageButton.html#a646b175c55ac588b8ffed117f213e8e2',1,'ImageButton::hitTest()'],['../classPositionedGlyph.html#a92491e5bb26267dfa36bb54fc0be7d0e',1,'PositionedGlyph::hitTest()']]],
-  ['horizontal_125',['horizontal',['../classColourGradient.html#a95e4615b53d8c257903269522397f587',1,'ColourGradient::horizontal(Colour colour1, float x1, Colour colour2, float x2)'],['../classColourGradient.html#a62381b6286d9175e4e8451e9b4e5c035',1,'ColourGradient::horizontal(Colour colourLeft, Colour colourRight, Rectangle&lt; Type &gt; area)']]],
-  ['hostmidicontrollerisavailable_126',['hostMIDIControllerIsAvailable',['../classAudioProcessorEditor.html#a0e943df67341fbed55d08b93f6773170',1,'AudioProcessorEditor']]],
-  ['hours_127',['hours',['../classRelativeTime.html#a1ae421b15cbeb81220bbf544a116cb77',1,'RelativeTime']]],
-  ['hwndcomponent_128',['HWNDComponent',['../classHWNDComponent.html#a078cb399434604a7059c7f37813501ea',1,'HWNDComponent']]],
-  ['hyperlinkbutton_129',['HyperlinkButton',['../classHyperlinkButton.html#aab8c9244ad8e28df8d012bbb3fb5b89f',1,'HyperlinkButton::HyperlinkButton(const String &amp;linkText, const URL &amp;linkURL)'],['../classHyperlinkButton.html#a6248ace276d2aade28ae1c61f33e76fa',1,'HyperlinkButton::HyperlinkButton()']]]
+  ['hasfocusoutline_80',['hasFocusOutline',['../classComponent.html#a5c60b638b3e2e692df18e63c6f8857df',1,'Component']]],
+  ['hash_81',['hash',['../classUuid.html#aaa9e337833ead2cb48039a09ddcd8106',1,'Uuid::hash()'],['../classString.html#a317bebf3259d5fefa6a2558b65ae2f77',1,'String::hash()']]],
+  ['hashcode_82',['hashCode',['../classFileInputSource.html#a95b676eefdd0f1b2978d9c31a6af5d10',1,'FileInputSource::hashCode()'],['../classString.html#ad8ca5cb11984df03ff9697442da5ae4b',1,'String::hashCode()'],['../classURLInputSource.html#a289bcfa8603911b61cd057ea0dd63646',1,'URLInputSource::hashCode()'],['../classInputSource.html#a1fe754d44724da8eaef055c496ca4140',1,'InputSource::hashCode()'],['../classAndroidDocumentInputSource.html#a385ea8cda7c0e56bd8b936c2da24a157',1,'AndroidDocumentInputSource::hashCode()'],['../classFile.html#ae5548575e6854b9837e5b42fc8df0e98',1,'File::hashCode() const']]],
+  ['hashcode64_83',['hashCode64',['../classFile.html#ad0075226638584f6fb30c0d515e182e9',1,'File::hashCode64()'],['../classString.html#ad71be66a9c181abae185b84f7cec5f17',1,'String::hashCode64()']]],
+  ['hashmap_84',['HashMap',['../classHashMap.html#a4d6d41cfc524ccc0a73f0251d7fc1fab',1,'HashMap']]],
+  ['hasidenticalcontentto_85',['hasIdenticalContentTo',['../classFile.html#ad3170a56847a243b475a72ccc9968089',1,'File']]],
+  ['haskeyboardfocus_86',['hasKeyboardFocus',['../classComponent.html#abf76cf5c3550c5c83bc585f86429b397',1,'Component']]],
+  ['hasmethod_87',['hasMethod',['../classDynamicObject.html#a530ccfe2318fb705fe4b4c9a07861788',1,'DynamicObject']]],
+  ['hasmmx_88',['hasMMX',['../classSystemStats.html#a245726d89f0a6cf232b70ff7d89652e5',1,'SystemStats']]],
+  ['hasmousecursor_89',['hasMouseCursor',['../classMouseInputSource.html#ad2b2d3176e07d9672e949dc88135f532',1,'MouseInputSource']]],
+  ['hasmousewheel_90',['hasMouseWheel',['../classMouseInputSource.html#a691068a9661fb11b3e7b10f51a4254b0',1,'MouseInputSource']]],
+  ['hasmovedsignificantlysincepressed_91',['hasMovedSignificantlySincePressed',['../classMouseInputSource.html#a50d0b35cef0fc91851c18e0c242f6adc',1,'MouseInputSource']]],
+  ['hasname_92',['hasName',['../structGridItem_1_1Property.html#a7ef06fbb3b2ad9644c11b54d2ed6986d',1,'GridItem::Property']]],
+  ['hasneon_93',['hasNeon',['../classSystemStats.html#a0e193b24d50ed44287099c8fbd879311',1,'SystemStats']]],
+  ['hasproperty_94',['hasProperty',['../classDynamicObject.html#a600910b3145a802f247b456f95b43e5f',1,'DynamicObject::hasProperty()'],['../classvar.html#a1ac3c09cc21b32c4baa0f520c8783908',1,'var::hasProperty()'],['../classValueTree.html#a0dbec0d665fb9d57b9fd7b3189ec0ee0',1,'ValueTree::hasProperty()']]],
+  ['hasreadaccess_95',['hasReadAccess',['../classFile.html#a9d46c7ee5e292e0a5d6720e979cf4a96',1,'File']]],
+  ['hassametypeas_96',['hasSameTypeAs',['../classvar.html#a6357525c383c7d52c43d1db7d0669f34',1,'var']]],
+  ['hasseparateinputsandoutputs_97',['hasSeparateInputsAndOutputs',['../classAudioIODeviceType.html#ac87c3129c8e55018e968225b4a47dc74',1,'AudioIODeviceType']]],
+  ['hasspan_98',['hasSpan',['../structGridItem_1_1Property.html#a1e9afac3f936a5a048b15ee2784d7a92',1,'GridItem::Property']]],
+  ['hassse_99',['hasSSE',['../classSystemStats.html#ad5f3b624e4b0d32db1c5702ee039a765',1,'SystemStats']]],
+  ['hassse2_100',['hasSSE2',['../classSystemStats.html#a55e24b924d9c64e019f1efe1888d2963',1,'SystemStats']]],
+  ['hassse3_101',['hasSSE3',['../classSystemStats.html#aa9ffa8da005c3311eda3ee34ecdd5b28',1,'SystemStats']]],
+  ['hassse41_102',['hasSSE41',['../classSystemStats.html#ab46b181da7ecf6c0f96e865b1a91e6f3',1,'SystemStats']]],
+  ['hassse42_103',['hasSSE42',['../classSystemStats.html#a1b3861b105869d8062a539142da7e741',1,'SystemStats']]],
+  ['hasssse3_104',['hasSSSE3',['../classSystemStats.html#afd53593c782c3770106954ace47ce25c',1,'SystemStats']]],
+  ['hasstopmessagebeensent_105',['hasStopMessageBeenSent',['../classMessageManager.html#a3b51c7c37417fea8c4f47ebb7913ddba',1,'MessageManager']]],
+  ['hasstreamfinished_106',['hasStreamFinished',['../classAudioTransportSource.html#a4914381d34ed8bff499ca878c2be83fb',1,'AudioTransportSource']]],
+  ['hastagname_107',['hasTagName',['../classXmlElement.html#ac50bc4ce0db92b84baf4baf1b9c4de1d',1,'XmlElement']]],
+  ['hastagnameignoringnamespace_108',['hasTagNameIgnoringNamespace',['../classXmlElement.html#abcf184f1ddfb5cbec32f20b9adefb4c7',1,'XmlElement']]],
+  ['hastype_109',['hasType',['../classValueTree.html#a5d41bc2066cae65b69aa614aa0f68ff1',1,'ValueTree']]],
+  ['hasvalue_110',['hasValue',['../classOptional.html#a526be66da8e92b60541e15593093bee3',1,'Optional::hasValue()'],['../classAndroidDocument.html#a40516a17b35a5125fb9cadc948eb4f8b',1,'AndroidDocument::hasValue()']]],
+  ['haswatchedcomponentbeendeleted_111',['hasWatchedComponentBeenDeleted',['../classPopupMenu_1_1Options.html#a6411ef9fb0d046aaa1c9b1e8c8a7e1e4',1,'PopupMenu::Options']]],
+  ['haswriteaccess_112',['hasWriteAccess',['../classFile.html#a5335004d1a8ec1673c616358adee00e7',1,'File']]],
+  ['heapblock_113',['HeapBlock',['../classHeapBlock.html#a720865797ff4f5e9e92432b0b231d110',1,'HeapBlock::HeapBlock()=default'],['../classHeapBlock.html#a7b5c4b5a56551744a36f68eefc27f6d7',1,'HeapBlock::HeapBlock(SizeType numElements)'],['../classHeapBlock.html#a6fa48a9a24fa7b9b84967c1c6aa29e24',1,'HeapBlock::HeapBlock(SizeType numElements, bool initialiseToZero)'],['../classHeapBlock.html#a43e44081c3cbef5f634dd5a2a58cd1bd',1,'HeapBlock::HeapBlock(HeapBlock &amp;&amp;other) noexcept'],['../classHeapBlock.html#a43360d0b67112a64db4c131cfe976a31',1,'HeapBlock::HeapBlock(HeapBlock&lt; OtherElementType, otherThrowOnFailure &gt; &amp;&amp;other) noexcept']]],
+  ['heavyweightleakedobjectdetector_114',['HeavyweightLeakedObjectDetector',['../classHeavyweightLeakedObjectDetector.html#ae84f4df4ce1826d3bf438bab330d2831',1,'HeavyweightLeakedObjectDetector::HeavyweightLeakedObjectDetector() noexcept'],['../classHeavyweightLeakedObjectDetector.html#a05a37f04096dfe2c59d654f87fb91c5f',1,'HeavyweightLeakedObjectDetector::HeavyweightLeakedObjectDetector(const HeavyweightLeakedObjectDetector &amp;) noexcept']]],
+  ['hexagonal_115',['hexagonal',['../classAudioChannelSet.html#a7ed53c9a23d40bd2dd50e1d7129837f8',1,'AudioChannelSet']]],
+  ['hide_116',['hide',['../classProcess.html#a01a7ddde215bcef03cd16587ed4b0a64',1,'Process']]],
+  ['hidecursor_117',['hideCursor',['../classMouseInputSource.html#a61bc07273b91b328bcff92e721a2461e',1,'MouseInputSource']]],
+  ['hideeditor_118',['hideEditor',['../classLabel.html#a6f5fd9653da51af4720d1ac5e54f18d8',1,'Label']]],
+  ['hideinfobubble_119',['hideInfoBubble',['../classSystemTrayIconComponent.html#ad9e5f01b380d85df60bc76dcb07baefc',1,'SystemTrayIconComponent']]],
+  ['hidepopup_120',['hidePopup',['../classComboBox.html#a68c3355b300f275af9962d772665fd53',1,'ComboBox']]],
+  ['hidetextbox_121',['hideTextBox',['../classSlider.html#a0780c7da80f4d487703e8247e92bea21',1,'Slider']]],
+  ['hidetip_122',['hideTip',['../classTooltipWindow.html#a917c164d878207aceb22a1c71a541731',1,'TooltipWindow']]],
+  ['hidewaitcursor_123',['hideWaitCursor',['../classMouseCursor.html#a4671d39f6abcc1ca73fd8d95cf1e4355',1,'MouseCursor']]],
+  ['highresolutiontickstoseconds_124',['highResolutionTicksToSeconds',['../classTime.html#a3c4d54513d5d2be78a790cfd0b8c0493',1,'Time']]],
+  ['highresolutiontimer_125',['HighResolutionTimer',['../classHighResolutionTimer.html#ac79eb2389b1d52cd4a387836fe9ce860',1,'HighResolutionTimer']]],
+  ['hirestimercallback_126',['hiResTimerCallback',['../classHighResolutionTimer.html#a38fac5960301220b28b687817e4e7598',1,'HighResolutionTimer']]],
+  ['hittest_127',['hitTest',['../classTabBarButton.html#ac6e24e3e9b5001e36a3014692257ea03',1,'TabBarButton::hitTest()'],['../classCallOutBox.html#a916cce375fb38ac4e77e4a8ef27591b6',1,'CallOutBox::hitTest()'],['../classLassoComponent.html#ab67925a4436687bc41437c8460de710d',1,'LassoComponent::hitTest()'],['../classResizableCornerComponent.html#acc3a046566ad8ab5aa5318b3a943d2fc',1,'ResizableCornerComponent::hitTest()'],['../classResizableBorderComponent.html#acd797e21238848968eb9957106590253',1,'ResizableBorderComponent::hitTest()'],['../classDrawableShape.html#ab5862ed42c7976a43791f56ae6173c27',1,'DrawableShape::hitTest()'],['../classDrawableImage.html#a0a6bd602f7d8dd85366b11b7419209ed',1,'DrawableImage::hitTest()'],['../classComponent.html#a2da9631236e1cbf1b340454209a6c9e0',1,'Component::hitTest()'],['../classImageButton.html#a646b175c55ac588b8ffed117f213e8e2',1,'ImageButton::hitTest()'],['../classPositionedGlyph.html#a92491e5bb26267dfa36bb54fc0be7d0e',1,'PositionedGlyph::hitTest()']]],
+  ['horizontal_128',['horizontal',['../classColourGradient.html#a95e4615b53d8c257903269522397f587',1,'ColourGradient::horizontal(Colour colour1, float x1, Colour colour2, float x2)'],['../classColourGradient.html#a62381b6286d9175e4e8451e9b4e5c035',1,'ColourGradient::horizontal(Colour colourLeft, Colour colourRight, Rectangle&lt; Type &gt; area)']]],
+  ['hostdriveneventloop_129',['HostDrivenEventLoop',['../classHostDrivenEventLoop.html#a3e2ac563f5a848fc092af8bd749545f4',1,'HostDrivenEventLoop']]],
+  ['hostmidicontrollerisavailable_130',['hostMIDIControllerIsAvailable',['../classAudioProcessorEditor.html#a0e943df67341fbed55d08b93f6773170',1,'AudioProcessorEditor']]],
+  ['hours_131',['hours',['../classRelativeTime.html#a1ae421b15cbeb81220bbf544a116cb77',1,'RelativeTime']]],
+  ['hwndcomponent_132',['HWNDComponent',['../classHWNDComponent.html#a078cb399434604a7059c7f37813501ea',1,'HWNDComponent']]],
+  ['hyperlinkbutton_133',['HyperlinkButton',['../classHyperlinkButton.html#aab8c9244ad8e28df8d012bbb3fb5b89f',1,'HyperlinkButton::HyperlinkButton(const String &amp;linkText, const URL &amp;linkURL)'],['../classHyperlinkButton.html#a6248ace276d2aade28ae1c61f33e76fa',1,'HyperlinkButton::HyperlinkButton()']]]
 ];
