@@ -48,7 +48,7 @@ var searchData=
   ['depth_45',['depth',['../namespacegl.html#a3dd0bd5abe8dc4f4464688156d2f99f0',1,'gl']]],
   ['depthbufferbits_46',['depthBufferBits',['../classOpenGLPixelFormat.html#a9783fd7c1c9d5ade28eac2eb7c710be4',1,'OpenGLPixelFormat']]],
   ['descent_47',['descent',['../classTextLayout_1_1Line.html#af361532452a96a85ccd9098e5269fbcd',1,'TextLayout::Line']]],
-  ['description_48',['description',['../structApplicationCommandInfo.html#a9d36981d292001925176c0be0d2e6b3a',1,'ApplicationCommandInfo::description()'],['../structOSCException.html#a1c71f609494bb48bb2c769ab25947205',1,'OSCException::description()'],['../structInAppPurchases_1_1Product.html#a985ca2010425d5805da7c761e3a4fc2a',1,'InAppPurchases::Product::description()'],['../structPushNotifications_1_1Channel.html#ae0400a494850c777027af736449c4cbf',1,'PushNotifications::Channel::description()'],['../classDragAndDropTarget_1_1SourceDetails.html#a48087c787b2d1f08f84ba7bd6c5c6eec',1,'DragAndDropTarget::SourceDetails::description()'],['../structNetworkServiceDiscovery_1_1Service.html#adc99ae2b16376f56d4e0f1b244edd1c0',1,'NetworkServiceDiscovery::Service::description()'],['../classFileFilter.html#a405f80abc17801d969bbaab30b4cec10',1,'FileFilter::description()']]],
+  ['description_48',['description',['../structInAppPurchases_1_1Product.html#a985ca2010425d5805da7c761e3a4fc2a',1,'InAppPurchases::Product::description()'],['../classFileFilter.html#a405f80abc17801d969bbaab30b4cec10',1,'FileFilter::description()'],['../structNetworkServiceDiscovery_1_1Service.html#adc99ae2b16376f56d4e0f1b244edd1c0',1,'NetworkServiceDiscovery::Service::description()'],['../structApplicationCommandInfo.html#a9d36981d292001925176c0be0d2e6b3a',1,'ApplicationCommandInfo::description()'],['../classDragAndDropTarget_1_1SourceDetails.html#a48087c787b2d1f08f84ba7bd6c5c6eec',1,'DragAndDropTarget::SourceDetails::description()'],['../structPushNotifications_1_1Channel.html#ae0400a494850c777027af736449c4cbf',1,'PushNotifications::Channel::description()'],['../structOSCException.html#a1c71f609494bb48bb2c769ab25947205',1,'OSCException::description()']]],
   ['descriptivename_49',['descriptiveName',['../classPluginDescription.html#a93ddf8b86e68316fc4746eb89c00b52c',1,'PluginDescription']]],
   ['destination_50',['destination',['../structAudioProcessorGraph_1_1Connection.html#a056525d39e5c9aa8b07ddd64183de544',1,'AudioProcessorGraph::Connection']]],
   ['destinationgpumask_51',['destinationGpuMask',['../namespacegl.html#a33eccdef4f3581f293781ae690fe45f0',1,'gl']]],
@@ -74,30 +74,31 @@ var searchData=
   ['dpi_71',['dpi',['../structDisplays_1_1Display.html#af9762583627b9e317179e9289bd1d4b8',1,'Displays::Display']]],
   ['dppass_72',['dppass',['../namespacegl.html#a937e14a3a472b03eecd091902b3ab515',1,'gl']]],
   ['drawableclippath_73',['drawableClipPath',['../classDrawable.html#a075bd445aa34244d2239f21a54faf487',1,'Drawable']]],
-  ['drawbuffer_74',['drawbuffer',['../namespacegl.html#aa1fa1722e95304e104bc2f2ce0d8ac69',1,'gl']]],
-  ['drawcount_75',['drawCount',['../namespacegl.html#a7286e0d147f3c4558109dcb78a2a03cc',1,'gl']]],
+  ['drawabletransform_74',['drawableTransform',['../classDrawable.html#a16938a961a921370c4c0bedd18267551',1,'Drawable']]],
+  ['drawbuffer_75',['drawbuffer',['../namespacegl.html#aa1fa1722e95304e104bc2f2ce0d8ac69',1,'gl']]],
   ['drawcount_76',['drawcount',['../namespacegl.html#ae3254e74141d463dbdcce7497e326cd6',1,'gl']]],
-  ['drawframebuffer_77',['drawFramebuffer',['../namespacegl.html#af8320e71f1d0ec460f03c3dfb3be726a',1,'gl']]],
-  ['drivercontrols_78',['driverControls',['../namespacegl.html#a912843399935f7db8800231f4d6c17b3',1,'gl']]],
-  ['drivercontrolstring_79',['driverControlString',['../namespacegl.html#a19300f9dddff0ed733b7d349e53a9be4',1,'gl']]],
-  ['drylevel_80',['dryLevel',['../structReverb_1_1Parameters.html#add75191e7a163d95cd807cbc72fa192c',1,'Reverb::Parameters']]],
-  ['dst_81',['dst',['../namespacegl.html#a174f1a72ee763b6703711da180ac5d79',1,'gl']]],
-  ['dstalpha_82',['dstAlpha',['../namespacegl.html#a076f998bca245288f127723bf5e1d45c',1,'gl']]],
-  ['dstgpu_83',['dstGpu',['../namespacegl.html#af18eff6b6be0d7608793d6b10aeb039f',1,'gl']]],
-  ['dstgpumask_84',['dstGpuMask',['../namespacegl.html#a5a5c80b79ff0c4478a449f393df4eb68',1,'gl']]],
-  ['dstlayouts_85',['dstLayouts',['../namespacegl.html#a649d88018455edaae0742fdfd14718b4',1,'gl']]],
-  ['dstlevel_86',['dstLevel',['../namespacegl.html#abd0090fef73959a6b78bdc7a379a54c1',1,'gl']]],
-  ['dstmask_87',['dstMask',['../namespacegl.html#a10030b231c8b946dbb3becfc366f971d',1,'gl']]],
-  ['dstmod_88',['dstMod',['../namespacegl.html#a6d45ae83ed4f0f25c95113d16076f1d4',1,'gl']]],
-  ['dstname_89',['dstName',['../namespacegl.html#a4614590f0452d4b54a835d2105ad48de',1,'gl']]],
-  ['dstrgb_90',['dstRGB',['../namespacegl.html#a69bb910aa6a879ded21e4ac323105fb7',1,'gl']]],
-  ['dsttarget_91',['dstTarget',['../namespacegl.html#a38c3d5a8d2f1da8c716ecf4ab6d2a4a0',1,'gl']]],
-  ['dstx_92',['dstX',['../namespacegl.html#ad7ff3679debbf5be43d43fc797d539f3',1,'gl']]],
-  ['dstx0_93',['dstX0',['../namespacegl.html#a667dc2085568856cc98c6a8c88d548c1',1,'gl']]],
-  ['dstx1_94',['dstX1',['../namespacegl.html#a93285e0294220776b0160b651eefd59c',1,'gl']]],
-  ['dsty_95',['dstY',['../namespacegl.html#a183f931150e84d96ab6a7165827351a0',1,'gl']]],
-  ['dsty0_96',['dstY0',['../namespacegl.html#a2d8ee4e06f834feab508f0c6f4b866b1',1,'gl']]],
-  ['dsty1_97',['dstY1',['../namespacegl.html#afb0f2c6874aa48575301cef47435c213',1,'gl']]],
-  ['dstz_98',['dstZ',['../namespacegl.html#a9f44234b35390bdbfecab1de1495d05c',1,'gl']]],
-  ['dtd_99',['dtd',['../structXmlElement_1_1TextFormat.html#a7a74f1a980b686aadba5df029afdef2a',1,'XmlElement::TextFormat']]]
+  ['drawcount_77',['drawCount',['../namespacegl.html#a7286e0d147f3c4558109dcb78a2a03cc',1,'gl']]],
+  ['drawframebuffer_78',['drawFramebuffer',['../namespacegl.html#af8320e71f1d0ec460f03c3dfb3be726a',1,'gl']]],
+  ['drivercontrols_79',['driverControls',['../namespacegl.html#a912843399935f7db8800231f4d6c17b3',1,'gl']]],
+  ['drivercontrolstring_80',['driverControlString',['../namespacegl.html#a19300f9dddff0ed733b7d349e53a9be4',1,'gl']]],
+  ['drylevel_81',['dryLevel',['../structReverb_1_1Parameters.html#add75191e7a163d95cd807cbc72fa192c',1,'Reverb::Parameters']]],
+  ['dst_82',['dst',['../namespacegl.html#a174f1a72ee763b6703711da180ac5d79',1,'gl']]],
+  ['dstalpha_83',['dstAlpha',['../namespacegl.html#a076f998bca245288f127723bf5e1d45c',1,'gl']]],
+  ['dstgpu_84',['dstGpu',['../namespacegl.html#af18eff6b6be0d7608793d6b10aeb039f',1,'gl']]],
+  ['dstgpumask_85',['dstGpuMask',['../namespacegl.html#a5a5c80b79ff0c4478a449f393df4eb68',1,'gl']]],
+  ['dstlayouts_86',['dstLayouts',['../namespacegl.html#a649d88018455edaae0742fdfd14718b4',1,'gl']]],
+  ['dstlevel_87',['dstLevel',['../namespacegl.html#abd0090fef73959a6b78bdc7a379a54c1',1,'gl']]],
+  ['dstmask_88',['dstMask',['../namespacegl.html#a10030b231c8b946dbb3becfc366f971d',1,'gl']]],
+  ['dstmod_89',['dstMod',['../namespacegl.html#a6d45ae83ed4f0f25c95113d16076f1d4',1,'gl']]],
+  ['dstname_90',['dstName',['../namespacegl.html#a4614590f0452d4b54a835d2105ad48de',1,'gl']]],
+  ['dstrgb_91',['dstRGB',['../namespacegl.html#a69bb910aa6a879ded21e4ac323105fb7',1,'gl']]],
+  ['dsttarget_92',['dstTarget',['../namespacegl.html#a38c3d5a8d2f1da8c716ecf4ab6d2a4a0',1,'gl']]],
+  ['dstx_93',['dstX',['../namespacegl.html#ad7ff3679debbf5be43d43fc797d539f3',1,'gl']]],
+  ['dstx0_94',['dstX0',['../namespacegl.html#a667dc2085568856cc98c6a8c88d548c1',1,'gl']]],
+  ['dstx1_95',['dstX1',['../namespacegl.html#a93285e0294220776b0160b651eefd59c',1,'gl']]],
+  ['dsty_96',['dstY',['../namespacegl.html#a183f931150e84d96ab6a7165827351a0',1,'gl']]],
+  ['dsty0_97',['dstY0',['../namespacegl.html#a2d8ee4e06f834feab508f0c6f4b866b1',1,'gl']]],
+  ['dsty1_98',['dstY1',['../namespacegl.html#afb0f2c6874aa48575301cef47435c213',1,'gl']]],
+  ['dstz_99',['dstZ',['../namespacegl.html#a9f44234b35390bdbfecab1de1495d05c',1,'gl']]],
+  ['dtd_100',['dtd',['../structXmlElement_1_1TextFormat.html#a7a74f1a980b686aadba5df029afdef2a',1,'XmlElement::TextFormat']]]
 ];
