@@ -12,7 +12,7 @@ var searchData=
   ['markertag_9',['markerTag',['../classMarkerList_1_1ValueTreeWrapper.html#a6ee3f514e213161c74b047b9bc6011d2',1,'MarkerList::ValueTreeWrapper']]],
   ['maroon_10',['maroon',['../namespaceColours.html#afb8d50495ddad76d8a45e385e88387a4',1,'Colours']]],
   ['mask_11',['mask',['../namespacegl.html#ab9d63f1ad694ba31b9ba3bcb44ba8cb7',1,'gl']]],
-  ['masterpitchbendrange_12',['masterPitchbendRange',['../structMPEZoneLayout_1_1Zone.html#a90c96070a462a3d4439d375425717065',1,'MPEZoneLayout::Zone']]],
+  ['masterpitchbendrange_12',['masterPitchbendRange',['../structMPEZone.html#a630f3a2724d4f64f94f83907de9dfd84',1,'MPEZone']]],
   ['mat_13',['mat',['../classMatrix3D.html#ad7e9eecc94c0a33a029a5de12c5c056b',1,'Matrix3D']]],
   ['mat00_14',['mat00',['../classAffineTransform.html#a1e675f5137df72253566699cd385c7ad',1,'AffineTransform']]],
   ['mat01_15',['mat01',['../classAffineTransform.html#ac253c675d087474d5fcb83d5b6025496',1,'AffineTransform']]],
@@ -25,8 +25,8 @@ var searchData=
   ['maxactivecounters_22',['maxActiveCounters',['../namespacegl.html#a984a08142063b4c8197a0a0c28b4b563',1,'gl']]],
   ['maxbuffers_23',['maxBuffers',['../namespacegl.html#a475fbb78313ecad529a109394e559fab',1,'gl']]],
   ['maxcount_24',['maxCount',['../namespacegl.html#a65f3dd1cb128c1d509627ff1bcf5fb5c',1,'gl']]],
-  ['maxdrawcount_25',['maxdrawcount',['../namespacegl.html#ac0003839033ba12b417b60c13cb0fe17',1,'gl']]],
-  ['maxdrawcount_26',['maxDrawCount',['../namespacegl.html#a37a758a3b2b152024491a8dd85e9c2c8',1,'gl']]],
+  ['maxdrawcount_25',['maxDrawCount',['../namespacegl.html#a37a758a3b2b152024491a8dd85e9c2c8',1,'gl']]],
+  ['maxdrawcount_26',['maxdrawcount',['../namespacegl.html#ac0003839033ba12b417b60c13cb0fe17',1,'gl']]],
   ['maxframebuffers_27',['maxFramebuffers',['../namespacegl.html#ac009b5bab0c604785ab4c2e9c50bf1b6',1,'gl']]],
   ['maxheight_28',['maxHeight',['../classGridItem.html#aebe1c6bf8c616570acf4021b32d9572a',1,'GridItem::maxHeight()'],['../classFlexItem.html#a166fa48e4268692cce0419f8ed5ad56a',1,'FlexItem::maxHeight()']]],
   ['maximumblocksize_29',['maximumBlockSize',['../structdsp_1_1ProcessSpec.html#aa57b782ce7ef5dd262ed688b39d7ac26',1,'dsp::ProcessSpec']]],
